fixed spelling
diff --git a/frc971/control_loops/index/index.h b/frc971/control_loops/index/index.h
index 0be4801..e6902d8 100644
--- a/frc971/control_loops/index/index.h
+++ b/frc971/control_loops/index/index.h
@@ -317,9 +317,9 @@
   LoaderGoal loader_goal_;
   LoaderState loader_state_;
   int loader_countdown_, loader_timeout_;
   // Whether or not we (might have) failed to shoot a disk that's now (probably)
   // still in the loader.
-  bool disk_stuck_in_loader_;
+  bool disc_stuck_in_loader_;
 
   // Current state of the pistons.
   bool loader_up_;
@@ -317,9 +317,9 @@
   LoaderState loader_state_;
   int loader_countdown_, loader_timeout_;
-  // Whether or not we (might have) failed to shoot a disk that's now (probably)
+  // Whether or not we (might have) failed to shoot a disc that's now (probably)
   // still in the loader.